==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/content/fluids/transfer/FillingRecipe.java <==
package com.zurrtum.create.content.fluids.transfer;

import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.mojang.serialization.DynamicOps;
import com.mojang.serialization.JsonOps;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.AllRecipeSerializers;
import com.zurrtum.create.AllRecipeTypes;
import com.zurrtum.create.foundation.fluid.FluidIngredient;
import com.zurrtum.create.foundation.recipe.CreateRecipe;
import com.zurrtum.create.infrastructure.component.SequencedAssemblyJunk;
import net.minecraft.class_1799;
import net.minecraft.class_1856;
import net.minecraft.class_1865;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3956;
import net.minecraft.class_7225;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public record FillingRecipe(class_1799 result, class_1856 ingredient, FluidIngredient fluidIngredient) implements CreateRecipe<FillingInput> {
    @Override
    public boolean matches(FillingInput input, class_1937 world) {
        return ingredient.method_8093(input.item()) && fluidIngredient.test(input.fluid());
    }

    @Override
    public class_1799 craft(FillingInput input, class_7225.class_7874 registries) {
        SequencedAssemblyJunk junk = input.item().method_58694(AllDataComponents.SEQUENCED_ASSEMBLY_JUNK);
        if (junk != null && junk.hasJunk()) {
            return junk.getJunk();
        }
        return result.method_7972();
    }

    @Override
    public class_1865<FillingRecipe> method_8119() {
        return AllRecipeSerializers.FILLING;
    }

    @Override
    public class_3956<FillingRecipe> method_17716() {
        return AllRecipeTypes.FILLING;
    }

    public static class_2561 getDescriptionForAssembly(DynamicOps<JsonElement> ops, JsonObject object) {
        return FluidIngredient.CODEC.parse(JsonOps.INSTANCE, object.get("fluid_ingredient")).result()
            .flatMap(fluidIngredient -> fluidIngredient.getMatchingFluidStacks().stream().findFirst())
            .map(stack -> class_2561.method_43469("create.recipe.assembly.spout_filling_fluid", stack.getName().getString()))
            .orElseGet(() -> class_2561.method_43470("Invalid"));
    }

    public static class Serializer implements class_1865<FillingRecipe> {
        public static final MapCodec<FillingRecipe> CODEC = RecordCodecBuilder.mapCodec(instance -> instance.group(
            class_1799.field_24671.fieldOf("result").forGetter(FillingRecipe::result),
            class_1856.field_46095.fieldOf("ingredient").forGetter(FillingRecipe::ingredient),
            FluidIngredient.CODEC.fieldOf("fluid_ingredient").forGetter(FillingRecipe::fluidIngredient)
        ).apply(instance, FillingRecipe::new));
        public static final class_9139<class_9129, FillingRecipe> PACKET_CODEC = class_9139.method_56436(
            class_1799.field_48349,
            FillingRecipe::result,
            class_1856.field_48355,
            FillingRecipe::ingredient,
            FluidIngredient.PACKET_CODEC,
            FillingRecipe::fluidIngredient,
            FillingRecipe::new
        );

        @Override
        public MapCodec<FillingRecipe> method_53736() {
            return CODEC;
        }

        @Override
        public class_9139<class_9129, FillingRecipe> method_56104() {
            return PACKET_CODEC;
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/fluids/transfer/FillingRecipe.java <==
package com.zurrtum.create.content.fluids.transfer;

import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.mojang.serialization.DynamicOps;
import com.mojang.serialization.JsonOps;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.AllRecipeSerializers;
import com.zurrtum.create.AllRecipeTypes;
import com.zurrtum.create.foundation.fluid.FluidIngredient;
import com.zurrtum.create.foundation.recipe.CreateRecipe;
import com.zurrtum.create.infrastructure.component.SequencedAssemblyJunk;
import net.minecraft.class_1799;
import net.minecraft.class_1856;
import net.minecraft.class_1865;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3956;
import net.minecraft.class_7225;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public record FillingRecipe(class_1799 result, class_1856 ingredient, FluidIngredient fluidIngredient) implements CreateRecipe<FillingInput> {
    @Override
    public boolean matches(FillingInput input, class_1937 world) {
        return ingredient.method_8093(input.item()) && fluidIngredient.test(input.fluid());
    }

    @Override
    public class_1799 assemble(FillingInput input, class_7225.class_7874 registries) {
        SequencedAssemblyJunk junk = input.item().method_58694(AllDataComponents.SEQUENCED_ASSEMBLY_JUNK);
        if (junk != null && junk.hasJunk()) {
            return junk.getJunk();
        }
        return result.method_7972();
    }

    @Override
    public class_1865<FillingRecipe> method_8119() {
        return AllRecipeSerializers.FILLING;
    }

    @Override
    public class_3956<FillingRecipe> method_17716() {
        return AllRecipeTypes.FILLING;
    }

    public static class_2561 getDescriptionForAssembly(DynamicOps<JsonElement> ops, JsonObject object) {
        return FluidIngredient.CODEC.parse(JsonOps.INSTANCE, object.get("fluid_ingredient")).result()
            .flatMap(fluidIngredient -> fluidIngredient.getMatchingFluidStacks().stream().findFirst())
            .map(stack -> class_2561.method_43469("create.recipe.assembly.spout_filling_fluid", stack.getName().getString()))
            .orElseGet(() -> class_2561.method_43470("Invalid"));
    }

    public static class Serializer implements class_1865<FillingRecipe> {
        public static final MapCodec<FillingRecipe> CODEC = RecordCodecBuilder.mapCodec(instance -> instance.group(
            class_1799.field_24671.fieldOf("result").forGetter(FillingRecipe::result),
            class_1856.field_46095.fieldOf("ingredient").forGetter(FillingRecipe::ingredient),
            FluidIngredient.CODEC.fieldOf("fluid_ingredient").forGetter(FillingRecipe::fluidIngredient)
        ).apply(instance, FillingRecipe::new));
        public static final class_9139<class_9129, FillingRecipe> PACKET_CODEC = class_9139.method_56436(
            class_1799.field_48349,
            FillingRecipe::result,
            class_1856.field_48355,
            FillingRecipe::ingredient,
            FluidIngredient.PACKET_CODEC,
            FillingRecipe::fluidIngredient,
            FillingRecipe::new
        );

        @Override
        public MapCodec<FillingRecipe> method_53736() {
            return CODEC;
        }

        @Override
        public class_9139<class_9129, FillingRecipe> method_56104() {
            return PACKET_CODEC;
        }
    }
}
